==> tune_reporting-0.9.28.zip: tune_reporting-0.9.28/CHANGES.md <==
## tune-reporting-python Changelog
=======================

Here you can see the full list of changes between each `tune-reporting-python` release.

Version 0.9.0
--------------

Internal release on October 06, 2014
* TUNE Client for Python 3.0

Version 0.9.1
--------------

Internal release on October 12, 2014
* TUNE Advertise Reports

Version 0.9.2
--------------

Internal release on October 14, 2014
* Unittests and Examples

Version 0.9.3
--------------

Internal release on October 18, 2014
* TUNE Client for Python 2.7 and Python 3.0

Version 0.9.5
--------------

Initial public release on October 22, 2014
* Field validation for parameter fields, sort, filter, group

Version 0.9.6
--------------

Beta public release on October 23, 2014
* Refactored layout of setup, examples, and tests.

Version 0.9.7
--------------

Beta public release on October 27, 2014
* Removed threading from fetch()
* Provided recommended values for exports()

Version 0.9.8
--------------

Beta public release on October 28, 2014
* Unittest fixes for Jenkins

Version 0.9.9
--------------

Beta public release on October 28, 2014
* fetch() and status() on all reporting classes.

Version 0.9.10
--------------

Beta public release on October 30, 2014
* Created endpoint base classes.
* Removed bash scripts and provided Makefile instead.

Version 0.9.11
--------------

Beta public release on October 31, 2014
* Revised fetch to use controller/action.

Version 0.9.12
--------------

Beta public release on October 31, 2014
* Refactor: Class names of service module.
* Python 3.0 fixes.

Version 0.9.13
--------------

Beta public release on Novenber 03, 2014
* Documentation reST compliant.
* Sphinx generated documentation.
* Report Reader fixed

Version 0.9.14
--------------

Beta public release on Novenber 06, 2014
* Fixes to Cohort and Actuals reports

Version 0.9.16
--------------

Beta public release on Novenber 19, 2014
* Fixes to Cohort and Retention reports

Version 0.9.20
--------------

Beta public release on December 10, 2014
* Refactored to accomodate *tune-reporting-python*

Version 0.9.23
--------------

Beta public release on December 19, 2014
* SDK Configuration *tune_reporting_sdk.config* file.

Version 0.9.24
--------------

Beta public release on December 21, 2014
* Refactored base endpoints.
* /advertiser/stats/ltv is now referred to ad Value reporting.

Version 0.9.26
--------------

Beta public release on December 24, 2014
* Refactored Log and Cohort classes.
* Tune Management API request contains SDK name and version.

Version 0.9.28
--------------

Beta public release on December 30, 2014
* TUNE Management API request contains 'sdk' and 'ver'.

==> tune_reporting-0.9.32.zip: tune_reporting-0.9.32/CHANGES.md <==
## tune-reporting-python Changelog
=======================

Here you can see the full list of changes between each `tune-reporting-python` release.

Version 0.9.0
--------------

Internal release on October 06, 2014
* TUNE Client for Python 3.0

Version 0.9.1
--------------

Internal release on October 12, 2014
* TUNE Advertise Reports

Version 0.9.2
--------------

Internal release on October 14, 2014
* Unittests and Examples

Version 0.9.3
--------------

Internal release on October 18, 2014
* TUNE Client for Python 2.7 and Python 3.0

Version 0.9.5
--------------

Initial public release on October 22, 2014
* Field validation for parameter fields, sort, filter, group

Version 0.9.6
--------------

Beta public release on October 23, 2014
* Refactored layout of setup, examples, and tests.

Version 0.9.7
--------------

Beta public release on October 27, 2014
* Removed threading from fetch()
* Provided recommended values for exports()

Version 0.9.8
--------------

Beta public release on October 28, 2014
* Unittest fixes for Jenkins

Version 0.9.9
--------------

Beta public release on October 28, 2014
* fetch() and status() on all reporting classes.

Version 0.9.10
--------------

Beta public release on October 30, 2014
* Created endpoint base classes.
* Removed bash scripts and provided Makefile instead.

Version 0.9.11
--------------

Beta public release on October 31, 2014
* Revised fetch to use controller/action.

Version 0.9.12
--------------

Beta public release on October 31, 2014
* Refactor: Class names of service module.
* Python 3.0 fixes.

Version 0.9.13
--------------

Beta public release on Novenber 03, 2014
* Documentation reST compliant.
* Sphinx generated documentation.
* Report Reader fixed

Version 0.9.14
--------------

Beta public release on Novenber 06, 2014
* Fixes to Cohort and Actuals reports

Version 0.9.16
--------------

Beta public release on Novenber 19, 2014
* Fixes to Cohort and Retention reports

Version 0.9.20
--------------

Beta public release on December 10, 2014
* Refactored to accomodate *tune-reporting-python*

Version 0.9.23
--------------

Beta public release on December 19, 2014
* SDK Configuration *tune_reporting_sdk.config* file.

Version 0.9.24
--------------

Beta public release on December 21, 2014
* Refactored base endpoints.
* /advertiser/stats/ltv is now referred to ad Value reporting.

Version 0.9.26
--------------

Beta public release on December 24, 2014
* Refactored Log and Cohort classes.
* Tune Management API request contains SDK name and version.

Version 0.9.28
--------------

Beta public release on December 30, 2014
* TUNE Management API request contains 'sdk' and 'ver'.

Version 0.9.32
--------------

Beta public release on January 03, 2015
* Provide toJson() within response.
* Created 'config' directory to hold TUNE Reporting SDK configuration.
